package fr.inria.gemo.util;

/**
 * <p>
 * This class provides utility functions over <code>String</code> objects.
 * </p>
 * @author Jerome Baumgarten jerome.baumgarten@inria.fr
 * @version 1.0
 */
public class StringUtils {

	/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
	*
	* Constants.
	*
	* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	/**
	 * A constant representing the empty <code>String</code>: "".
	 */
	static public final String EMPTY_STRING = "";

	/**
	 * Tests if two <code>String</code> objects are equal.
	 * If the two <code>String</code>s are <code>null</code>, they are
	 * considered equal. Otherwise it uses the <code>equals</code> method of
	 * the <code>String</code> class.
	 * @param s1 the first <code>String</code> to compare.
	 * @param s2 the second <code>String</code> to compare.
	 * @return <code>true</code> if the two <code>String</code>s are equal, 
	 * <code>false</code> otherwise.
	 */
	static public boolean Equal(String s1, String s2) {
		// return (s1 != null) && (s2 != null) && s1.equals(s2);
		return ((s1 == null) && (s2 == null))
			|| ((s1 != null) && (s2 != null) && s1.equals(s2));
	}

	/**
	 * Tests if a <code>String</code> is empty, i.e <code>null</code> or
	 * equals to the empty <code>String</code> ("").
	 * @param s the <code>String</code> to test.
	 * @return <code>true</code> if the <code>String</code> is <code>null</code>
	 * or equals to the empty <code>String</code> ("").
	 */
	static public boolean IsEmpty(String s) {
		return (s == null) || EMPTY_STRING.equals(s);
	}

	/**
	 * Creates a <code>String</code> composed of <code>nb</code> times the
	 * <code>String</code> s. For example, the following call:
	 * <code>StringUtils.CreateRepeatedString("abc",3);</code>
	 * returns "abcabcabc".
	 * @param s the <code>String</code> to repeat.
	 * @param nb the number of times you want to repeat the <code>String</code> s.
	 * @return an empty <code>String</code> if nb is less or equal to 0 or if s is an
	 * empty <code>String</code>. Otherwise, it returns a <code>String</code>
	 * composed of <code>nb</code> times the <code>String</code> s.
	 */
	static public String CreateRepeatedString(String s, int nb) {
		if (nb <= 0)
			return EMPTY_STRING;
		StringBuffer buffer = new StringBuffer(s);
		int nbIter = nb - 1;
		for (int i = 0; i < nbIter; i++)
			buffer.append(s);
		return buffer.toString();
	}

	static public String ToString(String[] strings) {
		StringBuffer sBuffer = new StringBuffer("[");
		if ( (strings != null) && (strings.length > 0) ) {
			for(int i=0 ; i<(strings.length-1) ; i++) {
				sBuffer.append(strings[i]);
				sBuffer.append(',');
			}
			sBuffer.append(strings[strings.length-1]);
		}
		sBuffer.append(']');
		return sBuffer.toString();
	}

	// For now it is just BS
	//	static public boolean onlyContains(String s, char[] chars) {
	//		char[] sChars = s.toCharArray();
	//		int length = sChars.length;
	//		for(int i=0 ; i<length ; i++) {
	//			if (!belongsTo(sChars[i],chars))
	//				return false;
	//		}
	//		return true;
	//	}
	//
	//	static public boolean belongsTo(char c, char[] chars) {
	//		int length = chars.length;
	//		for(int i=0 ; i<length ; i++) {
	//			if (chars[i] == c)
	//				return true;
	//		}
	//		return false;
	//	}
	//
	//	static public boolean containsOnlySpaceChar(String s) {
	//		char[] chars = s.toCharArray();
	//		int nbChars = chars.length;;
	//		for(int i=0 ; i<nbChars ; i++)
	//			if (! Character.isSpaceChar(chars[i]))
	//				return false;
	//		return true;
	//	}
	//
	//	static public boolean containsOnlyWhitespace(String s) {
	//		char[] chars = s.toCharArray();
	//		int nbChars = chars.length;;
	//		for(int i=0 ; i<nbChars ; i++)
	//			if (! Character.isWhitespace(chars[i]))
	//				return false;
	//		return true;
	//	}
}