package fr.inria.gemo.util;

import java.util.logging.Logger;

/**
 * @author <a href="mailto:Jerome.Baumgarten@inria.fr">Jerome Baumgarten</a>
 */
public class ThreadUtils {
	/* It does a deep waitForCompletion, i.e. it will wait for all the threads
	 * of the ThreadGroup and of its subgroups.
	 */
	static public void WaitForCompletion(
		ThreadGroup group,
		long timeout,
		Logger logger) {
		logger.fine(
			"Waiting for completion of ThreadGroup "
				+ group.getName()
				+ " with timeout "
				+ timeout);
		int l = group.activeCount();
		Thread[] threads = new Thread[l];
		group.enumerate(threads);
		logger.finer(
			"ThreadGroup " + group.getName() + " contains " + l + " Thread(s)");
		for (int i = 0; i < l; i++) {
			if (threads[i] == null) {
				logger.finest("Thread index " + i + " is null :-(");
				continue;
			}
			logger.finer(
				"Waiting for completion of Thread " + threads[i].getName());
			try {
				threads[i].join(timeout);
			} catch (InterruptedException IEx) {
				logger.warning(
					"Caught InterruptedException while joining Thread "
						+ threads[i].getName()
						+ "\n"
						+ IEx.getLocalizedMessage());
			}
			logger.finer("Thread " + threads[i].getName() + " completed");
		}
		logger.fine("ThreadGroup " + group.getName() + " completed");
		logger.fine(
			"After completion, ThreadGroup "
				+ group.getName()
				+ " contains "
				+ group.activeCount()
				+ " Thread(s)");
	}

}
