package fr.inria.gemo.util;

/**
 * <p>
 * This class describes the configuration used for the pretty printing of an XML document or node.
 * You can specify if you want to use tabulations or space characters (including the number) 
 * for indentation. You can also specify what should be used for a new line. It is also
 * possible to discard "empty" text nodes.
 * </p>
 * @author Jerome Baumgarten jerome.baumgarten@inria.fr
 * @version 1.0
 */
public class XMLPrettyPrinterConfiguration extends PrettyPrinterConfiguration {

	/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
	*
	* Data members.
	*
	* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	/**
	 * Indicates if the empty text nodes of the document should be considered for the
	 * pretty printing.
	 * A text node is considered empty if the <code>trim</code>ed <code>String</code>
	 * of the text node equals the empty: "" <code>String</code>.
	 */
	public boolean discardEmptyTextNode = true;

	/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
	*
	* Constructors.
	*
	* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	/**
	 * Constructs a new XMLPrettyPrinterConfiguration.
	 */
	public XMLPrettyPrinterConfiguration() {
		super();
	}

	/**
	 * Constructs a new XMLPrettyPrinterConfiguration.
	 * @param useTab indicates if tabulations should be use for the indentation.
	 * @param space represents the number of spaces to use for indentation if not
	 * using tabulation.
	 * @param newline represents the <code>String</code> used to do a new line.
	 */
	public XMLPrettyPrinterConfiguration(
		boolean useTab,
		short space,
		String newline) {
		super(useTab, space, newline);
	}

	/**
	 * Constructs a new XMLPrettyPrinterConfiguration.
	 * @param useTab indicates if tabulations should be use for the indentation.
	 * @param space represents the number of spaces to use for indentation if not
	 * using tabulation.
	 * @param newline represents the <code>String</code> used to do a new line.
	 * @param discardEmptyTextNode indicates if empty text nodes should be printed or not.
	 * A text node is considered empty if the <code>trim</code>ed <code>String</code>
	 * of the text node equals the empty: "" <code>String</code>.
	 */
	public XMLPrettyPrinterConfiguration(
		boolean useTab,
		short space,
		String newline,
		boolean discardEmptyTextNode) {
		this(useTab, space, newline);
		this.discardEmptyTextNode = discardEmptyTextNode;
	}

	/**
	 * Constructs a new XMLPrettyPrinterConfiguration from a <code>PrettyPrinterConfiguration</code>
	 * <code>Object</code>.
	 * @param config the <code>PrettyPrinterConfiguration</code> used to create this
	 * <code>Object</code>.
	 * @see fr.inria.gemo.util.PrettyPrinterConfiguration
	 */
	public XMLPrettyPrinterConfiguration(PrettyPrinterConfiguration config) {
		this(config.useTab, config.space, config.newline);
		super.indent = config.indent;
	}
}
