/*
 * Created on 7 juil. 2003
 */
package fr.inria.gemo.util.xml;

import java.util.Iterator;
import java.util.Map;

import javax.xml.parsers.ParserConfigurationException;
import javax.xml.transform.TransformerException;

import org.apache.xpath.XPathAPI;

import org.w3c.dom.Attr;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

/**
 * @author Jrme Baumgarten
 */
public class PropertiesToXML {

	final static private String PROPERTIES_ELEMENT = "properties";
	final static private String VALUE_ATTRIBUTE = "value";

	private Document document = null;
	private Element properties = null;

	public PropertiesToXML(Map propertiesMap) {
		try {
			this.document = XMLUtils.CreateNewDocument(true);
			this.properties = this.document.createElementNS(null, PROPERTIES_ELEMENT);
			this.document.appendChild(this.properties);
			this.addProperties(propertiesMap);
		} catch (ParserConfigurationException PCEx) {
		}
	}

	public Document getDocument() {
		return this.document;
	}

	public void addProperties(Map propertiesMap) {
		Iterator iterator = propertiesMap.entrySet().iterator();
		while (iterator.hasNext()) {
			Map.Entry entry = (Map.Entry) iterator.next();
			String propertyName = (String) entry.getKey();
			String propertyValue = (String) entry.getValue();
			this.setProperty(propertyName, propertyValue);
		}
	}

	public void setProperty(String propertyName, String propertyValue) {
		int split = -1;
		String name = propertyName;
		Element current = this.properties;
		Element targetElement = null;
		while ( (split = name.indexOf(".")) != -1) {
			String token = name.substring(0, split);
			name = name.substring(split+1);
			// check for existing Element
			if ( (targetElement = XMLUtils.GetFirstChildElementByTagNameNS(current, null, token)) == null) {
				targetElement = this.document.createElementNS(null, token);
				current.appendChild(targetElement);
			}
			current = targetElement;
		}

		if ( (targetElement = XMLUtils.GetFirstChildElementByTagNameNS(current, null, name)) == null) {
			targetElement = this.document.createElementNS(null, name);
			current.appendChild(targetElement);
		}

		targetElement.setAttributeNS(null, VALUE_ATTRIBUTE, propertyValue);
	}

	public String getPropertyValue(String propertyName) {
		String expression = propertyName.replace('.', '/') + "/@" + VALUE_ATTRIBUTE;
		System.out.println(expression);
		Node node = null;
		try {
			node = XPathAPI.selectSingleNode(this.properties, expression);
		} catch (TransformerException e) {
		}
		if (node != null) {
			System.out.println(DOMSerializer.Serialize(node));
		}
		if ( (node != null) && (node.getNodeType() == Node.ATTRIBUTE_NODE) ) {
			Attr attr = (Attr) node;
			return attr.getNodeValue();
		}
		return null;
	}

	static public void main(String[] args) {
		Map propertiesMap = new java.util.HashMap();
		propertiesMap.put("axml.peer.url", "http://localhost:8080/axml");
		propertiesMap.put("axml.peer.log.size", "5242880");
		propertiesMap.put("axml.peer.log.file", "/axml.log");
		propertiesMap.put("axml.dr.dataguides.construction", "true");
		propertiesMap.put("axml.webapp.addons.auctions.name", "Auction Demo");
		propertiesMap.put("axml.webapp.addons.auctions.location", "/auctions");
		propertiesMap.put("axml.webapp.addons.auctions.user.name", "Bob");
		PropertiesToXML properties = new PropertiesToXML(propertiesMap);
		System.out.println(DOMSerializer.Serialize(properties.getDocument()));
		properties.setProperty("axml.peer.log.size", "1");
		System.out.println(DOMSerializer.Serialize(properties.getDocument()));
		System.out.println(properties.getPropertyValue("axml.peer"));
		System.out.println(properties.getPropertyValue("axml.peer.url"));
		System.out.println(properties.getPropertyValue("axml.peer.log.size"));
	}
}
